The function glob.change computes a set of three global change metrics for comparison
between two polygon sets. These metrics are outlined in Robertson et al. (2007; Table 4).
glob.change(T1, T2)A list object with three elements - Results for the NumRatio, AreaRatio, and AvgAreaRatio metrics.
a sf object of polygons from time 1.
a sf object of polygons from time 2.
glob.change computes three change metrics, detailed below, that can be used to quantify changes
between two polygon sets:
NumRatio -- ratio between the number of polygons in T2 and T1;
$$\mathtt{NumRatio} = \frac{\#(T1)}{\#(T2)}$$
AreaRatio -- ratio between the areas of polygons in T2 and T1;
$$\mathtt{AreaRatio} = \frac{A(T2)}{A(T1)}$$
AvgAreaRatio -- ratio between the AreaRatio and NumRatio;
$$\mathtt{AvgAreaRatio} = \frac{\mathtt{AreaRatio}}{\mathtt{NumRatio}} = \frac{\frac{A(T2)}{A(T1)}}{\frac{\#(T1)}{\#(T2)}}$$